AI LIB
Include MathUtil，MsLearn，DeepLearn，CVUtil，NPLUtil

Author： itproject-manager.com

package publish ref doc
1.python setup.py sdist build
2.twine upload dist/*
Jo2022/Milenfan123
3.pip install itprojectai==1.0.x
from itproject.mathbasic import MatrixUtil
http://t.zoukankan.com/jinjiangongzuoshi-p-14037220.html

project pip address
https://pypi.org/project/itprojectai/